@@ -10,12 +10,13 @@
             [puppetlabs.ssl-utils.core :refer [pem->cert]]
             [puppetlabs.ssl-utils.simple :as ssl-simple]
             [puppetlabs.trapperkeeper.app :refer [get-service]]
-            [puppetlabs.trapperkeeper.services.webserver.jetty9-service :refer :all]
+            [puppetlabs.trapperkeeper.services.webserver.jetty10-service :refer :all]
             [puppetlabs.trapperkeeper.testutils.bootstrap :refer [with-app-with-config]]
             [puppetlabs.trapperkeeper.testutils.logging :as logutils]
             [ring.util.response :as rr]
             [schema.core :as schema]
-            [slingshot.slingshot :as slingshot]))
+            [slingshot.slingshot :as slingshot])
+  (:import (com.fasterxml.jackson.core JsonFactory JsonLocation JsonParseException JsonParser)))
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -127,7 +128,7 @@
 (defmacro with-target-and-proxy-servers
   [{:keys [target proxy proxy-handler ring-handler endpoint target-endpoint]} & body]
   `(with-app-with-config proxy-target-app#
-     [jetty9-service]
+     [jetty10-service]
      {:webserver ~target}
      (let [target-webserver# (get-service proxy-target-app# :WebserverService)]
        (add-ring-handler
@@ -143,7 +144,7 @@
         post-target-handler
         "/hello/post"))
      (with-app-with-config proxy-app#
-       [jetty9-service]
+       [jetty10-service]
        {:webserver ~proxy}
        (let [proxy-webserver# (get-service proxy-app# :WebserverService)]
          (add-ring-handler proxy-webserver# ~proxy-handler ~endpoint))
@@ -748,4 +749,56 @@
         (is (= handled-response (wrapped-handler get-request)))
         (is (= handled-response (wrapped-handler put-request)))
         (is (= handled-response (wrapped-handler post-request)))
-        (is (= handled-response (wrapped-handler delete-request)))))))
\ No newline at end of file
+        (is (= handled-response (wrapped-handler delete-request)))))))
+
+(deftest wrap-accepts-json-test
+  (let [request (fn [method a] {:request-method method :headers {"accept" a}})
+        handler (constantly nil)
+        wrapped-handler (core/wrap-accepts-json handler)]
+    (testing "wrap-accepts-json allows json"
+      (let []
+        (doseq [method [:get :put :post :delete]]
+          (is (nil? (wrapped-handler (request method "application/json"))))
+          (is (nil? (wrapped-handler (request method "text/html, application/json"))))
+          (is (nil? (wrapped-handler (request method "application/*"))))
+          (is (nil? (wrapped-handler (request method "*/*")))))))
+    (testing "wrap-accepts-json rejects non-json"
+      (let [rejection-expectation
+            {:body    "{\"kind\":\"not-acceptable\",\"msg\":\"accept header must include application/json\"}"
+             :headers {"Content-Type" "application/json; charset=utf-8"}
+             :status  406}]
+        (doseq [method [:get :put :post :delete]]
+          (let [result (wrapped-handler (request method "text/html"))]
+            (is (= rejection-expectation result))))))))
+
+(deftest wrap-content-type-json-test
+  (let [request (fn [method a] {:request-method method :headers {"content-type" a} :uri "http://example.com"})
+        handler (constantly nil)
+        wrapped-handler (core/wrap-content-type-json handler)]
+   (testing "wrap-content-type-json allows json"
+     (let []
+       (doseq [method [:put :post]]
+         (is (nil? (wrapped-handler (request method "application/json")))))
+       ;; content-type is ignored for get and delete
+       (doseq [method [:get :delete]]
+         (is (nil? (wrapped-handler (request method "text/html, application/json"))))
+         (is (nil? (wrapped-handler (request method "application/*"))))
+         (is (nil? (wrapped-handler (request method "*/*"))))))
+   (testing "wrap-content-type-json rejects non-json"
+     (let [rejection-expectation
+           (fn [method]
+             {:body    (str "{\"kind\":\"unsupported-type\",\"msg\":\"content-type text/html is not a supported type for request of type " method " at http://example.com\"}")
+             :headers {"Content-Type" "application/json; charset=utf-8"}
+             :status  415})]
+       (doseq [method [:put :post]]
+         (let [result (wrapped-handler (request method "text/html"))]
+           (is (= (rejection-expectation method) result)))))))))
+
+(deftest wrap-json-parse-exception-handler-test
+  (let [factory (JsonFactory.)
+        wrapped-handler (core/wrap-json-parse-exception-handler (fn [_] (throw (JsonParseException. (.createParser factory "") "Error Message" ))))
+        response (wrapped-handler (basic-request))]
+    (is (= {:body    "{\"kind\":\"json-parse-exception\",\"msg\":\"Error Message\\n at [Source: (String)\\\"\\\"; line: 1, column: 1]\"}"
+            :headers {"Content-Type" "application/json; charset=utf-8"}
+            :status  400}
+           response))))
\ No newline at end of file
